Enum yara_sys::errors::CompileErrorLevel [−][src]
pub enum CompileErrorLevel {
Error,
Warning,
}Expand description
The level of an error while parsing a rule file.
Variants
Implementations
Convert from an i32 error code.
Returns Err if the code is not a valide value.